-- Tests for the HazLoot core functions

require("WoWMock")
require("Core")
require("HSK")

function TestSetup()
  print("*** Setting up tests")
  HazLoot.OnInitialize()
  WM:AddParty()
  print("*** Setup succeeded")
end

function TestTeardown()
  print("*** Tearing down tests")
  print("*** Teardown succeeded")
end

function TestXXX()
  print("*** Testing HazLoot:XXX()")
  WM:CleanUp()
  print("*** HazLoot:XXX() is working as expected.")
end

function TestGetItemId()
  print("*** Testing HazLoot:GetItemId(itemLink)")
  WM:CreateCorpse(WM.THREEGUN)
  assert(41168 == WM.corpse[2], "Expected 2nd slot to have a combat shotgun")
  local tmp = HazLoot:GetItemId(GetLootSlotLink(2))
  assert(41168 == tmp, "Expected itemId to be 41168, not: "..(tmp or "nil"))
  WM:CleanUp()
  print("*** HazLoot:GetItemId(itemLink) is working as expected.")
end

function TestLootThatBag()
  print("*** Testing HazLoot:LootThatBag()")
  assert(0 == #HazLoot.PhatLewt, "Expected PhatLewt to be empty")
  assert(HazLoot.STATE_IDLE == HazLoot.State, "Expected HazLoot to be IDLE")

  print("\n* Testing an empty bag *")
  WM:CreateCorpse(WM.EMPTY)
  HazLoot:LootThatBag()
  assert(0 == #HazLoot.PhatLewt, "Expected PhatLewt to be empty")
  assert(HazLoot.STATE_IDLE == HazLoot.State, "Expected HazLoot to be IDLE")

  print("\n* Testing a money-only bag *")
  WM:CreateCorpse(WM.MONEYONLY)
  assert(0 < #WM.corpse, "Corpse should not be empty")
  HazLoot:LootThatBag()
  WM:CloseCorpse()
  assert(0 == #WM.corpse, "Corpse should be empty")
  assert(0 == #HazLoot.PhatLewt, "Expected PhatLewt to be empty")
  assert(HazLoot.STATE_IDLE == HazLoot.State, "Expected HazLoot to be IDLE")

  print("\n* Testing a corpse with cash and five greens - five in party, one not master loot eligible *")
  WM:CreateCorpse(WM.FIVEGREEN)
  assert(6 == #WM.corpse, "Corpse should have six slots: money + 5 greens")
  HazLoot:LootThatBag()
  WM:CloseCorpse()
  assert(0 == #WM.corpse, "Corpse should be empty")
  -- Expected behaviour?

  WM:CreateCorpse(WM.MIXED)
  assert(0 < #WM.corpse, "Corpse should not be empty")
  HazLoot:LootThatBag()
  assert(1 == HazLoot.CurrentItem, "Should be item #1")
  assert(4 == HazLoot.PhatLewt[HazLoot.CurrentItem].slot, "Should be slot 4")
  assert(0 < #WM.corpse, "Corpse should not be empty")
  assert(0 ~= #HazLoot.PhatLewt, "PhatLewt should not be empty")
  assert(2 == #HazLoot.PhatLewt, "PhatLewt should have 2 items")
  assert(HazLoot.STATE_BID_OPEN == HazLoot.State, "Expected HazLoot to be BID_OPEN")
  WM:CloseCorpse()
  HazLoot:LootThatBag()
  assert(1 == HazLoot.CurrentItem, "Should be item #1")
  assert(2 == HazLoot.PhatLewt[HazLoot.CurrentItem].slot, "Should be slot 2")
  assert(0 < #WM.corpse, "Corpse should not be empty")
  assert(0 ~= #HazLoot.PhatLewt, "PhatLewt should not be empty")
  assert(2 == #HazLoot.PhatLewt, "PhatLewt should have 2 items")
  assert(HazLoot.STATE_BID_OPEN == HazLoot.State, "Expected HazLoot to be BID_OPEN")
  WM:CloseCorpse()

  WM:CleanUp()
  print("*** HazLoot:LootThatBag() is working as expected.")
end

TestSetup()
TestGetItemId()
TestLootThatBag()
TestTeardown()
